Name:       voxelands
Version:    1410.00
Release:    3%{?dist}
Summary:    The Fun-Focused Free Software Voxel World Game

# bundled(jthread) uses MIT
License:    GPLv3 and MIT and CC-BY-SA
URL:        http://www.voxelands.com
Source0:    http://www.voxelands.com/downloads/%{name}-%{version}-src.tar.bz2
Source1:    %{name}.service
Source2:    default.conf
Source3:    README.fedora

# same reason as: https://fedorahosted.org/fpc/ticket/347
Provides: bundled(jthread)
BuildRequires:  cmake >= 2.6.0
BuildRequires:  irrlicht-devel bzip2-devel gettext-devel libsqlite3x-devel
BuildRequires:  libpng-devel libjpeg-turbo-devel libXxf86vm-devel mesa-libGL-devel
BuildRequires:  openal-soft-devel libvorbis-devel libogg-devel desktop-file-utils

Requires: hicolor-icon-theme

%description
Voxelands is a sandbox construction game based on Minetest, which was inspired by 
earlier "voxel world" games such as Infiniminer. Gameplay puts players in a fully 
destructible 3D game world where they can place and dig numerous types of blocks, 
items and creatures using a variety of tools. Inside the game world players can 
build structures, artworks and anything else their creativity can think of on 
multiplayer servers and singleplayer worlds across multiple game modes.

%package server
Summary: Voxelands multiplayer server
Requires(pre): shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description server
Voxelands multiplayer server. This package does not require X Windows System.

%prep
%setup -q -n %{name}


%build
# RUN_IN_PLACE gets configuration from project source directory
# bundled(jthread) is being linked from project source if
# -DBUILD_SHARED_LIBS:BOOL=ON (which is default behaviour)
%cmake -DRUN_IN_PLACE=0 -DBUILD_SHARED_LIBS=OFF
make VERBOSE=1 %{?_smp_mflags}


%install
%make_install

# add desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications misc/freedesktop/%{name}.desktop

# Systemd unit file
mkdir -p %{buildroot}%{_unitdir}/
install -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}

# /var/lib/voxelands directory for server data files
install -d -m 0775 %{buildroot}%{_sharedstatedir}/%{name}/

# /etc/voxelands/default.conf
install -d -m 0775 %{buildroot}%{_sysconfdir}/%{name}/
install    -m 0664 %{name}.conf.example %{buildroot}%{_sysconfdir}/%{name}/${name}.conf

# /etc/sysconfig/default.conf
install -d -m 0775 %{buildroot}%{_sysconfdir}/sysconfig/
install    -m 0664 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

cp -p %{SOURCE3} README.fedora


%find_lang %{name}

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%pre server
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sharedstatedir}/%{name} -s /sbin/nologin \
    -c "Voxelands Multiplayer Server" %{name}
exit 0

%post server
%systemd_post %{name}.service

%preun server
%systemd_preun %{name}.service

%postun server
%systemd_postun_with_restart %{name}.service 


%files -f %{name}.lang
%doc doc/changelog.txt doc/gpl-3.0.txt src/jthread/LICENSE.MIT README.fedora
%{_bindir}/%{name}
%{_datadir}/%{name}
%dir %{_docdir}/%{name}
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_datadir}/icons/hicolor/192x192/apps/%{name}.png
%{_datadir}/icons/hicolor/22x22/apps/%{name}.png
%{_datadir}/icons/hicolor/24x24/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man6/voxelands.*

%files server
%doc README.txt doc/gpl-3.0.txt src/jthread/LICENSE.MIT doc/mapformat.txt doc/protocol.txt README.fedora
%{_bindir}/%{name}-server
%{_datadir}/%{name}
%dir %{_docdir}/%{name}
%{_unitdir}/%{name}.service
%attr(-,voxelands,voxelands)%{_sharedstatedir}/%{name}/
%attr(-,voxelands,voxelands)%{_sysconfdir}/%{name}/
%attr(-,voxelands,voxelands)%{_sysconfdir}/sysconfig/%{name}
%{_mandir}/man6/voxelands-server.*


%changelog
* Mon Oct 27 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1410.00-3
- Remove unnecessary files.

* Sat Oct 25 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1410.00-2
- Bump to 1410.00-2, typo for getent

* Sat Oct 25 2014 Ye Myat Kaung <mavjs01@gmail.com> = 1410.00-1
- Package version bumped to 1410.00 since it's the latest stable release.

* Wed Oct 01 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-4
- Default flag in cmake macro causing libjthread.so errors.
- Turned off with -DBUILD_SHARED_LIBS:BOOL=OFF

* Thu Sep 25 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-3
- Packaged both server and client.
- This got rid of -DBUILD_SERVER=0

* Sat Sep 20 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-2
- Make changes according to review

* Thu Sep 11 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-1
- Initial package of voxelands 1409.00 for Fedora repos.
